<?php

/**
 * @file
 * Admin page callbacks for the contest module.
 */

/**
 * Menu callback to configure module settings.
 */
function contest_settings_form() {
  $nintey = array(ContestStorage::DAY * 90 => t('90 Days'));

  $form['#submit'][] = 'contest_settings_form_submit';
  $form['#validate'][] = 'contest_settings_form_validate';

  $form['desc'] = array(
    '#type'   => 'item',
    '#value'  => t('Configuration options for the contest module.'),
    '#weight' => 0,
  );
  $form['contest_dq_days'] = array(
    '#title'         => t('Days Between Wins'),
    '#type'          => 'select',
    '#options'       => ContestHelper::optionInsert(ContestStorage::getPeriodOptions(), $nintey),
    '#default_value' => variable_get('contest_dq_days', 90),
    '#required'      => TRUE,
    '#weight'        => 20,
  );
  $form['host'] = array(
    '#type'              => 'textfield',
    '#title'             => t('Host'),
    '#autocomplete_path' => 'contest/usr-autocomplete',
    '#default_value'     => ContestStorage::getUserName(variable_get('contest_host_uid', 1)),
    '#size'              => 30,
  );
  $form['contest_host_title'] = array(
    '#title'         => t('Host Title'),
    '#description'   => t("The host's display title."),
    '#type'          => 'textfield',
    '#default_value' => variable_get('contest_host_title', 'Contest Host'),
    '#size'          => 30,
    '#maxlength'     => 60,
    '#required'      => TRUE,
    '#weight'        => 40,
  );
  $form['contest_min_age'] = array(
    '#title'         => t('Minumum Age'),
    '#description'   => t("The minimum age required to enter a contest."),
    '#type'          => 'select',
    '#options'       => array_combine(range(1, 100), range(1, 100)),
    '#default_value' => variable_get('contest_min_age', 18),
    '#required'      => TRUE,
    '#weight'        => 50,
  );
  $form['tnc'] = array(
    '#title'       => t('Terms & Conditions'),
    '#description' => t("The contest's terms and conditions."),
    '#type'        => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed'   => TRUE,
    '#weight'      => 60,
  );
  $form['tnc']['contest_block_tnc_content'] = array(
    '#type'          => 'text_format',
    '#default_value' => ContestStorage::getBlockBody(variable_get('contest_block_tnc', 0)),
    '#format'        => ContestStorage::getBlockFormat(variable_get('contest_block_tnc', 0)),
    '#required'      => FALSE,
    'token_help'     => array(
      '#dialog'      => TRUE,
      '#theme'       => 'token_tree',
      '#token_types' => array('contest', 'node', 'user'),
      '#weight'      => 10,
    ),
  );
  return system_settings_form($form);
}

/**
 * Custom submit function for the contest setting form.
 */
function contest_settings_form_submit($form, &$state) {
  $uid = ContestStorage::getUserId(trim($state['values']['host']));

  if ($uid) {
    variable_set('contest_host_uid', $uid);
  }
  // Update the T&C content.
  $fields = array(
    'body'   => $state['values']['contest_block_tnc_content']['value'],
    'format' => $state['values']['contest_block_tnc_content']['format'],
  );
  ContestStorage::updateBlock(variable_get('contest_block_tnc', 0), $fields);

  unset($state['input']['host']);
  unset($state['values']['host']);
  unset($state['input']['contest_block_tnc_content']);
  unset($state['values']['contest_block_tnc_content']);
}

/**
 * Custom validation function for the contest setting form.
 */
function contest_settings_form_validate($form, &$state) {

  // Non-existent contest host.
  $host = user_load_by_name($state['values']['host']);
  $host = new ContestUser($host->uid);

  if (empty($host->uid)) {
    form_set_error('host', t('No user with that name: @name.', array('@name' => $state['values']['host'])));
  }
  // Incomplete host profile.
  if (!$host->completeProfile('host')) {
    $opts = array('attributes' => array('target' => '_blank'));
    $args = array(
      '@name' => $state['values']['host'],
      '!link' => l(t('here'), "user/$host->uid/edit", $opts),
    );
    form_set_error('host', t('@name has an incomplete profile. If you have permission, you can click !link to edit.', $args));
  }
}
